import * as pipelines from 'aws-cdk-lib/pipelines';
import { Construct } from 'constructs';
export interface PipelineProps {
    /**
     * The name of the pipeline.
     */
    readonly pipelineName: string;
    /**
     * The name of the repository.
     */
    readonly repoName: string;
    /**
     * The branch of the repository to use.
     */
    readonly repoBranch: string;
    /**
     * The command to run in the synth step.
     */
    readonly synthCommand?: Array<string>;
    /**
     * The primary output directory.
     */
    readonly primaryOutputDirectory?: string;
}
/**
 * A CDK construct that creates a CodePipeline.
 */
export declare class PipelineCdk extends Construct {
    /**
     * The CodePipeline created by the construct.
     */
    readonly pipeline: pipelines.CodePipeline;
    /**
     * Constructs a new instance of the PipelineCdk class.
     * @param scope The parent construct.
     * @param id The name of the construct.
     * @param props The properties for the construct.
     * @default - No default properties.
     *  */
    constructor(scope: Construct, id: string, props: PipelineProps);
}
